@@ -12,22 +12,21 @@
 <context>
     <name>NmList</name>
     <message>
-        <location filename="../src/nmlist.ui" line="14"/>
         <source>Dialog</source>
-        <translation>Dialoogvenster</translation>
+        <translation type="vanished">Dialoogvenster</translation>
     </message>
     <message>
-        <location filename="../src/nmlist.ui" line="20"/>
+        <location filename="../src/nmlist.ui" line="17"/>
         <source>All information</source>
         <translation>Alle informatie</translation>
     </message>
     <message>
-        <location filename="../src/nmlist.ui" line="30"/>
+        <location filename="../src/nmlist.ui" line="27"/>
         <source>Active connections</source>
         <translation>Actieve verbindingen</translation>
     </message>
     <message>
-        <location filename="../src/nmlist.ui" line="40"/>
+        <location filename="../src/nmlist.ui" line="37"/>
         <source>Available wireless</source>
         <translation>Beschikbare draadloze verbindingen</translation>
     </message>
@@ -35,125 +34,140 @@
 <context>
     <name>NmModel</name>
     <message>
-        <location filename="../src/nmmodel.cpp" line="55"/>
+        <location filename="../src/nmmodel.cpp" line="56"/>
         <source>nm-tray - wireless password</source>
         <translation>nm-tray - draadloos wachtwoord</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="56"/>
+        <location filename="../src/nmmodel.cpp" line="57"/>
         <source>Password is needed for connection to &apos;%1&apos;:</source>
-        <translation>Het wachtwoord is benodigd om te verbinden met &apos;%1&apos;:</translation>
+        <translation>Wachtwoord vereist om te verbinden met &apos;%1&apos;:</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="744"/>
+        <location filename="../src/nmmodel.cpp" line="745"/>
         <source>root</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="746"/>
+        <location filename="../src/nmmodel.cpp" line="747"/>
         <source>active connection(s)</source>
         <translation>actieve verbinding(en)</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="748"/>
+        <location filename="../src/nmmodel.cpp" line="749"/>
         <source>connection(s)</source>
         <translation>verbinding(en)</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="750"/>
+        <location filename="../src/nmmodel.cpp" line="751"/>
         <source>device(s)</source>
         <translation>appara(a)t(en)</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="752"/>
+        <location filename="../src/nmmodel.cpp" line="753"/>
         <source>wifi network(s)</source>
         <translation>wi-fi-netwerk(en)</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1043"/>
+        <location filename="../src/nmmodel.cpp" line="1044"/>
         <source>unknown</source>
         <comment>hardware address</comment>
         <translation>onbekend</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1151"/>
+        <location filename="../src/nmmodel.cpp" line="1152"/>
         <source>General</source>
         <comment>Active connection information</comment>
         <translation>Algemeen</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1152"/>
+        <location filename="../src/nmmodel.cpp" line="1153"/>
         <source>Interface</source>
         <comment>Active connection information</comment>
         <translation>Uiterlijk</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1154"/>
+        <location filename="../src/nmmodel.cpp" line="1155"/>
         <source>Hardware Address</source>
         <comment>Active connection information</comment>
         <translation>Hardware-adres</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1156"/>
+        <location filename="../src/nmmodel.cpp" line="1157"/>
         <source>Driver</source>
         <comment>Active connection information</comment>
         <translation>Stuurprogramma</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1158"/>
+        <location filename="../src/nmmodel.cpp" line="1159"/>
         <source>Speed</source>
         <comment>Active connection information</comment>
         <translation>Snelheid</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1160"/>
-        <source> Kb/s</source>
-        <translation></translation>
+        <location filename="../src/nmmodel.cpp" line="1163"/>
+        <source>Kb/s</source>
+        <translation>Kb/s</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1162"/>
+        <location filename="../src/nmmodel.cpp" line="1165"/>
+        <source>Mb/s</source>
+        <translation>Mb/s</translation>
+    </message>
+    <message>
+        <location filename="../src/nmmodel.cpp" line="1167"/>
+        <source>Gb/s</source>
+        <translation>Gb/s</translation>
+    </message>
+    <message>
+        <location filename="../src/nmmodel.cpp" line="1169"/>
+        <source>Tb/s</source>
+        <translation>Tb/s</translation>
+    </message>
+    <message>
+        <location filename="../src/nmmodel.cpp" line="1172"/>
         <source>unknown</source>
         <comment>Speed</comment>
         <translation>onbekend</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1166"/>
+        <location filename="../src/nmmodel.cpp" line="1176"/>
         <source>Security</source>
         <comment>Active connection information</comment>
         <translation>Beveiliging</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1170"/>
+        <location filename="../src/nmmodel.cpp" line="1180"/>
         <source>IPv4</source>
         <comment>Active connection information</comment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1171"/>
+        <location filename="../src/nmmodel.cpp" line="1181"/>
         <source>IPv6</source>
         <comment>Active connection information</comment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1182"/>
+        <location filename="../src/nmmodel.cpp" line="1192"/>
         <source>IP Address</source>
         <comment>Active connection information</comment>
         <translation>IP-adres</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1184"/>
+        <location filename="../src/nmmodel.cpp" line="1194"/>
         <source>Subnet Mask</source>
         <comment>Active connection information</comment>
         <translation>Subnet-mask</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1193"/>
+        <location filename="../src/nmmodel.cpp" line="1203"/>
         <source>Default route</source>
         <comment>Active connection information</comment>
         <translation>Standaard route</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1199"/>
+        <location filename="../src/nmmodel.cpp" line="1209"/>
         <source>DNS(%1)</source>
         <comment>Active connection information</comment>
         <translation></translation>
@@ -194,7 +208,7 @@
     <message>
         <location filename="../src/tray.cpp" line="220"/>
         <source>NetworkManager(nm-tray)</source>
-        <translation></translation>
+        <translation>NetworkManager (nm-tray)</translation>
     </message>
     <message>
         <location filename="../src/tray.cpp" line="253"/>
@@ -224,7 +238,7 @@
     <message>
         <location filename="../src/tray.cpp" line="260"/>
         <source>Wifi - request scan</source>
-        <translation type="unfinished"></translation>
+        <translation>Zoeken naar Wi-Fi-netwerken</translation>
     </message>
     <message>
         <location filename="../src/tray.cpp" line="261"/>
@@ -244,17 +258,17 @@
     <message>
         <location filename="../src/tray.cpp" line="291"/>
         <source>nm-tray info</source>
-        <translation>nm-tray informatie</translation>
+        <translation>nm-tray-informatie</translation>
     </message>
     <message>
         <location filename="../src/tray.cpp" line="384"/>
         <source>%1 about</source>
-        <translation>%1 over</translation>
+        <translation>Over %1</translation>
     </message>
     <message>
         <location filename="../src/tray.cpp" line="385"/>
         <source>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is a simple Qt based frontend for &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</source>
-        <translation>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is eenvoudig, op Qt-gebaseerd frontend voor &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Versie: %1</translation>
+        <translation>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is een eenvoudig op Qt gebaseerd front-end voor &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Versie: %1</translation>
     </message>
 </context>
 <context>
